@@ -18,14 +18,13 @@ from shutil import which
 from threading import Thread
 
 from lollypop.art_base import BaseArt
-from lollypop.art_downloader import ArtDownloader
 from lollypop.tagreader import TagReader
 from lollypop.define import Lp, ArtSize
 from lollypop.objects import Album
 from lollypop.utils import escape, is_readonly
 
 
-class AlbumArt(BaseArt, ArtDownloader, TagReader):
+class AlbumArt(BaseArt, TagReader):
     """
          Manager album artwork
     """
@@ -37,9 +36,9 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
             Init radio art
         """
         BaseArt.__init__(self)
-        ArtDownloader.__init__(self)
         TagReader.__init__(self)
-        self._favorite = Lp().settings.get_value('favorite-cover').get_string()
+        self.__favorite = Lp().settings.get_value(
+                                                'favorite-cover').get_string()
 
     def get_album_cache_path(self, album, size):
         """
@@ -50,7 +49,7 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
         """
         filename = ''
         try:
-            filename = self._get_album_cache_name(album)
+            filename = self.__get_album_cache_name(album)
             cache_path_jpg = "%s/%s_%s.jpg" % (self._CACHE_PATH,
                                                filename,
                                                size)
@@ -80,12 +79,12 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
         if album.id is None:
             return None
         try:
-            filename = self._get_album_cache_name(album) + ".jpg"
+            filename = self.__get_album_cache_name(album) + ".jpg"
             paths = [
                 # Used when album.path is readonly
                 os.path.join(self._STORE_PATH, filename),
                 # Default favorite artwork
-                os.path.join(album.path, self._favorite),
+                os.path.join(album.path, self.__favorite),
                 # Used when having muliple albums in same folder
                 os.path.join(album.path, filename),
             ]
@@ -131,7 +130,7 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
             @return cairo surface
         """
         size *= scale
-        filename = self._get_album_cache_name(album)
+        filename = self.__get_album_cache_name(album)
         cache_path_jpg = "%s/%s_%s.jpg" % (self._CACHE_PATH, filename, size)
         pixbuf = None
 
@@ -172,7 +171,7 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
                                                                          ratio)
                 # Use default artwork
                 if pixbuf is None:
-                    self.download_album_art(album.id)
+                    self.cache_album_art(album.id)
                     return self.get_default_icon('folder-music-symbolic',
                                                  size,
                                                  scale)
@@ -216,9 +215,9 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
                 which("kid3-cli") is not None
             album = Album(album_id)
             path_count = Lp().albums.get_path_count(album.path)
-            filename = self._get_album_cache_name(album) + ".jpg"
+            filename = self.__get_album_cache_name(album) + ".jpg"
             if save_to_tags:
-                t = Thread(target=self._save_artwork_tags,
+                t = Thread(target=self.__save_artwork_tags,
                            args=(data, album))
                 t.daemon = True
                 t.start()
@@ -226,12 +225,12 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
             # Many albums with same path, suffix with artist_album name
             if path_count > 1:
                 artpath = os.path.join(album.path, filename)
-                if os.path.exists(os.path.join(album.path, self._favorite)):
-                    os.remove(os.path.join(album.path, self._favorite))
+                if os.path.exists(os.path.join(album.path, self.__favorite)):
+                    os.remove(os.path.join(album.path, self.__favorite))
             elif is_readonly(album.path):
                 artpath = os.path.join(self._STORE_PATH, filename)
             else:
-                artpath = os.path.join(album.path, self._favorite)
+                artpath = os.path.join(album.path, self.__favorite)
             # Update cover file if exists event if we have written to tags
             if not save_to_tags or os.path.exists(artpath):
                 stream = Gio.MemoryInputStream.new_from_data(data, None)
@@ -280,7 +279,7 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
             Remove cover from cache for album id
             @param album as Album
         """
-        filename = self._get_album_cache_name(album)
+        filename = self.__get_album_cache_name(album)
         try:
             for f in os.listdir(self._CACHE_PATH):
                 if re.search('%s_.*\.jpg' % re.escape(filename), f):
@@ -296,13 +295,13 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
         """
         pixbuf = None
         try:
-            infos = self.get_infos(filepath)
+            info = self.get_info(filepath)
             exist = False
-            if infos is not None:
-                (exist, sample) = infos.get_tags().get_sample_index('image', 0)
+            if info is not None:
+                (exist, sample) = info.get_tags().get_sample_index('image', 0)
                 # Some file store it in a preview-image tag
                 if not exist:
-                    (exist, sample) = infos.get_tags().get_sample_index(
+                    (exist, sample) = info.get_tags().get_sample_index(
                                                             'preview-image', 0)
             if exist:
                 (exist, mapflags) = sample.get_buffer().map(Gst.MapFlags.READ)
@@ -321,7 +320,7 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
 #######################
 # PRIVATE             #
 #######################
-    def _save_artwork_tags(self, data, album):
+    def __save_artwork_tags(self, data, album):
         """
             Save artwork in tags
             @param data as bytes
@@ -348,7 +347,7 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
             self.clean_album_cache(album)
             GLib.idle_add(self.album_artwork_update, album.id)
 
-    def _get_album_cache_name(self, album):
+    def __get_album_cache_name(self, album):
         """
             Get a uniq string for album
             @param album as Album
