@@ -30,12 +30,11 @@ class AlbumsDatabase:
         """
         self._cached_randoms = []
 
-    def add(self, name, artist_ids, year, path, popularity, mtime):
+    def add(self, name, artist_ids, path, popularity, mtime):
         """
             Add a new album to database
             @param Album name as string
             @param artist ids as int
-            @param year as int
             @param path as string
             @param mtime as int
             @return inserted rowid as int
@@ -43,11 +42,11 @@ class AlbumsDatabase:
         """
         with SqlCursor(Lp().db) as sql:
             result = sql.execute("INSERT INTO albums\
-                                  (name, no_album_artist, year,\
-                                  path, popularity, mtime)\
+                                  (name, no_album_artist,\
+                                  path, popularity, mtime, synced)\
                                   VALUES (?, ?, ?, ?, ?, ?)",
-                                 (name, artist_ids == [], year,
-                                  path, popularity, mtime))
+                                 (name, artist_ids == [],
+                                  path, popularity, mtime, 0))
             for artist_id in artist_ids:
                 sql.execute("INSERT INTO album_artists\
                              (album_id, artist_id)\
@@ -99,6 +98,17 @@ class AlbumsDatabase:
                                 (album_id, artist_id)\
                                 VALUES (?, ?)", (album_id, artist_id))
 
+    def set_synced(self, album_id, synced):
+        """
+            Set album synced
+            @param album id as int
+            @param synced as bool
+            @warning: commit needed
+        """
+        with SqlCursor(Lp().db) as sql:
+            sql.execute("UPDATE albums SET synced=? WHERE rowid=?",
+                        (synced, album_id))
+
     def set_year(self, album_id, year):
         """
             Set year
@@ -136,6 +146,30 @@ class AlbumsDatabase:
             except:  # Database is locked
                 pass
 
+    def get_synced_ids(self):
+        """
+            Get synced album ids
+        """
+        with SqlCursor(Lp().db) as sql:
+            result = sql.execute("SELECT rowid FROM albums\
+                                  WHERE synced=1")
+            return list(itertools.chain(*result))
+
+    def get_synced(self, album_id):
+        """
+            Get album synced status
+            @param album_id as int
+            @return synced as bool
+        """
+        with SqlCursor(Lp().db) as sql:
+            result = sql.execute("SELECT synced FROM albums WHERE\
+                                 rowid=?", (album_id,))
+
+            v = result.fetchone()
+            if v is not None:
+                return v[0]
+            return 0
+
     def get_mtime(self, album_id):
         """
             Get modification time
@@ -143,7 +177,7 @@ class AlbumsDatabase:
             @return modification time as int
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT mtime FROM albums WHERE\
+            result = sql.execute("SELECT synced FROM albums WHERE\
                                  rowid=?", (album_id,))
 
             v = result.fetchone()
@@ -200,35 +234,11 @@ class AlbumsDatabase:
                 return v[0]
             return 5
 
-    def get_id(self, album_name, artist_id, year):
-        """
-            Get non compilation album id
-            @param Album name as string,
-            @param artist id as int
-            @param year as int
-            @return Album id as int
-        """
-        with SqlCursor(Lp().db) as sql:
-            filters = (album_name, artist_id)
-            request = "SELECT rowid FROM albums where name=?\
-                       AND artist_id=? "
-            if year is None:
-                request += "AND year is null"
-            else:
-                request += "AND year =?"
-                filters += (year,)
-            result = sql.execute(request, filters)
-            v = result.fetchone()
-            if v is not None:
-                return v[0]
-            return None
-
-    def get_non_compilation_id(self, album_name, artist_ids, year):
+    def get_non_compilation_id(self, album_name, artist_ids):
         """
             Get non compilation album id
             @param Album name as string,
             @param artist ids as [int]
-            @param year as int
             @return Album id as int
         """
         with SqlCursor(Lp().db) as sql:
@@ -240,18 +250,14 @@ class AlbumsDatabase:
                        album_artists.album_id=albums.rowid AND (1=0 "
             for artist_id in artist_ids:
                 request += "OR artist_id=? "
-            if year is None:
-                request += ") AND year is null"
-            else:
-                filters += (year,)
-                request += ") AND year=?"
+            request += ")"
             result = sql.execute(request, filters)
             v = result.fetchone()
             if v is not None:
                 return v[0]
             return None
 
-    def get_compilation_id(self, album_name, year):
+    def get_compilation_id(self, album_name):
         """
             Get compilation id
             @param Album name as string,
@@ -259,14 +265,26 @@ class AlbumsDatabase:
             @return Album id as int
         """
         with SqlCursor(Lp().db) as sql:
-            if year is None:
-                result = sql.execute("SELECT rowid FROM albums where name=?\
-                                      AND no_album_artist=1\
-                                      AND year is null", (album_name,))
-            else:
-                result = sql.execute("SELECT rowid FROM albums where name=?\
-                                      AND no_album_artist=1\
-                                      AND year=?", (album_name, year))
+            result = sql.execute("SELECT rowid FROM albums where name=?\
+                                  AND no_album_artist=1", (album_name,))
+            v = result.fetchone()
+            if v is not None:
+                return v[0]
+            return None
+
+    def get_year_from_tracks(self, album_id):
+        """
+            Get album year based on tracks
+            Use most used year by tracks
+            @param album id as int
+        """
+        with SqlCursor(Lp().db) as sql:
+            result = sql.execute("SELECT year, COUNT(year) AS occurrence\
+                                  FROM tracks\
+                                  WHERE tracks.album_id=?\
+                                  GROUP BY year\
+                                  ORDER BY occurrence DESC\
+                                  LIMIT 1", (album_id,))
             v = result.fetchone()
             if v is not None:
                 return v[0]
@@ -353,7 +371,7 @@ class AlbumsDatabase:
             if v is not None:
                 path = v[0]
             if path != "" and not os.path.exists(path):
-                tracks = self.get_tracks(album_id, [], [])
+                tracks = self.get_track_ids(album_id, [], [])
                 if tracks:
                     filepath = Lp().tracks.get_path(tracks[0])
                     path = os.path.dirname(filepath)
@@ -478,7 +496,7 @@ class AlbumsDatabase:
             result = sql.execute(request, filters)
             return list(itertools.chain(*result))
 
-    def get_tracks(self, album_id, genre_ids, artist_ids):
+    def get_track_ids(self, album_id, genre_ids=[], artist_ids=[]):
         """
             Get tracks for album id
             @param album id as int
@@ -488,9 +506,9 @@ class AlbumsDatabase:
         """
         genre_ids = remove_static_genres(genre_ids)
         # Reset filters if not needed
-        if not self._has_genres(album_id):
+        if not self.__has_genres(album_id):
             genre_ids = []
-        if not self._has_artists(album_id):
+        if not self.__has_artists(album_id):
             artist_ids = []
         with SqlCursor(Lp().db) as sql:
             filters = (album_id,)
@@ -529,9 +547,9 @@ class AlbumsDatabase:
         """
         genre_ids = remove_static_genres(genre_ids)
         # Reset filters if not needed
-        if not self._has_genres(album_id):
+        if not self.__has_genres(album_id):
             genre_ids = []
-        if not self._has_artists(album_id):
+        if not self.__has_artists(album_id):
             artist_ids = []
         with SqlCursor(Lp().db) as sql:
             filters = (album_id,)
@@ -570,9 +588,9 @@ class AlbumsDatabase:
         """
         genre_ids = remove_static_genres(genre_ids)
         # Reset filters if not needed
-        if not self._has_genres(album_id):
+        if not self.__has_genres(album_id):
             genre_ids = []
-        if not self._has_artists(album_id):
+        if not self.__has_artists(album_id):
             artist_ids = []
         with SqlCursor(Lp().db) as sql:
             filters = (album_id, disc)
@@ -678,7 +696,7 @@ class AlbumsDatabase:
                 result = sql.execute(request, filters)
             return list(itertools.chain(*result))
 
-    def get_compilations(self, genre_ids=[]):
+    def get_compilation_ids(self, genre_ids=[]):
         """
             Get all compilations
             @param Filter genre ids as [int]
@@ -745,7 +763,7 @@ class AlbumsDatabase:
         with SqlCursor(Lp().db) as sql:
             result = sql.execute("SELECT albums.rowid\
                                   FROM albums\
-                                  WHERE name LIKE ?\
+                                  WHERE noaccents(name) LIKE ?\
                                   LIMIT 25", ('%' + string + '%',))
             return list(itertools.chain(*result))
 
@@ -758,7 +776,7 @@ class AlbumsDatabase:
         """
         try:
             ret = []
-            for track_id in self.get_tracks(album_id, [], []):
+            for track_id in self.get_track_ids(album_id, [], []):
                 artist_ids = Lp().tracks.get_artist_ids(track_id)
                 # Check if previous track and
                 # track do not have same artists
@@ -824,7 +842,7 @@ class AlbumsDatabase:
 #######################
 # PRIVATE             #
 #######################
-    def _has_genres(self, album_id):
+    def __has_genres(self, album_id):
         """
             Return True if album has more than one genre
             @param album id as int
@@ -840,7 +858,7 @@ class AlbumsDatabase:
                 return v[0] > 1
         return False
 
-    def _has_artists(self, album_id):
+    def __has_artists(self, album_id):
         """
             Return True if album has more than one artist
             @param album id as int
