@@ -174,7 +174,7 @@ class TracksDatabase:
                 return v[0]
             return ""
 
-    def get_year(self, album_id):
+    def get_year(self, track_id):
         """
             Get track year
             @param track id as int
@@ -182,7 +182,7 @@ class TracksDatabase:
         """
         with SqlCursor(Lp().db) as sql:
             result = sql.execute("SELECT year FROM tracks WHERE rowid=?",
-                                 (album_id,))
+                                 (track_id,))
             v = result.fetchone()
             if v and v[0]:
                 return str(v[0])
@@ -293,23 +293,6 @@ class TracksDatabase:
                 mtimes.update((row,))
             return mtimes
 
-    def get_infos(self, track_id):
-        """
-            Get all track informations for track id
-            @param Track id as int
-            @return (name as string, filepath as string,
-            duration as int, tracknumber as int, album_id as int)
-            Returned values can be (None, None, None, None)
-        """
-        with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT name, filepath,\
-                                  duration, album_id\
-                                  FROM tracks WHERE rowid=?", (track_id,))
-            v = result.fetchone()
-            if v is not None:
-                return v
-            return (None, None, None, None)
-
     def get_paths(self):
         """
             Get all tracks filepath
@@ -571,7 +554,7 @@ class TracksDatabase:
         """
         with SqlCursor(Lp().db) as sql:
             result = sql.execute("SELECT rowid, name FROM tracks\
-                                  WHERE name LIKE ? LIMIT 25",
+                                  WHERE noaccents(name) LIKE ? LIMIT 25",
                                  ('%' + searched + '%',))
             return list(result)
 
