@@ -34,14 +34,15 @@ class DatabaseUpgrade:
         self._UPGRADES = {
             1: "UPDATE tracks SET duration=CAST(duration as INTEGER);",
             2: "UPDATE albums SET artist_id=-2001 where artist_id=-999;",
-            3: self._upgrade_3,
-            4: self._upgrade_4,
+            3: self.__upgrade_3,
+            4: self.__upgrade_4,
             5: "CREATE index idx_aa ON album_artists(album_id)",
             6: "CREATE index idx_ta ON track_artists(track_id)",
             7: "ALTER TABLE tracks ADD discname TEXT",
             8: "CREATE index idx_ag ON album_genres(album_id)",
             9: "CREATE index idx_tg ON track_genres(track_id)",
             10: "UPDATE tracks set ltime=0 where ltime is null",
+            11: "ALTER TABLE albums ADD synced INT NOT NULL DEFAULT 0",
                          }
 
     """
@@ -71,7 +72,7 @@ class DatabaseUpgrade:
 #######################
 # PRIVATE             #
 #######################
-    def _upgrade_3(self):
+    def __upgrade_3(self):
         """
             Add a sorted field to artists
         """
@@ -88,7 +89,7 @@ class DatabaseUpgrade:
                             (row[1], row[0]))
             sql.commit()
 
-    def _upgrade_4(self):
+    def __upgrade_4(self):
         """
             Add album artists table
         """
