@@ -192,15 +192,15 @@ class Album(Base):
             @return list of int
         """
         if self._track_ids is None:
-            self._track_ids = self.db.get_tracks(self.id,
-                                                 self.genre_ids,
-                                                 self.artist_ids)
+            self._track_ids = self.db.get_track_ids(self.id,
+                                                    self.genre_ids,
+                                                    self.artist_ids)
             # If user tagged track with an artist not present in album
             if not self._track_ids:
                 print("%s missing an album artist in artists" % self.name)
-                self._track_ids = self.db.get_tracks(self.id,
-                                                     self.genre_ids,
-                                                     [])
+                self._track_ids = self.db.get_track_ids(self.id,
+                                                        self.genre_ids,
+                                                        [])
         return self._track_ids
 
     @property
@@ -238,8 +238,8 @@ class Track(Base):
     """
     FIELDS = ['name', 'album_id', 'album_artist_ids',
               'artist_ids', 'album_name', 'artists',
-              'genres', 'duration', 'number', 'path', 'position']
-    DEFAULTS = ['', None, [], [], '', '', '', 0.0, None, '', 0]
+              'genres', 'duration', 'number', 'path', 'position', 'year']
+    DEFAULTS = ['', None, [], [], '', '', '', 0.0, None, '', 0, None]
 
     def __init__(self, track_id=None):
         """
@@ -307,14 +307,6 @@ class Track(Base):
         """
         return Album(self.album_id)
 
-    @property
-    def year(self):
-        """
-            Get track year
-            @return str
-        """
-        return self.album.year
-
     @property
     def album_artists(self):
         """
