@@ -92,6 +92,7 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
         if self._locked:
             return
         if self._next_track.id is not None:
+            self._scrobble(self.current_track, self._start_time)
             self.load(self._next_track)
         else:
             self.stop()
@@ -237,7 +238,7 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
             Play album
             @param album as Album
         """
-        if self.is_party():
+        if self.is_party:
             self.set_party(False)
         self.reset_history()
         # We are not playing a user playlist anymore
@@ -287,14 +288,14 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
            (artist_ids and artist_ids[0] == Type.ALL):
             # Genres: all, Artists: compilations
             if artist_ids and artist_ids[0] == Type.COMPILATIONS:
-                self._albums += Lp().albums.get_compilations()
+                self._albums += Lp().albums.get_compilation_ids()
             # Genres: all, Artists: ids
             elif artist_ids and artist_ids[0] != Type.ALL:
                 self._albums += Lp().albums.get_ids(artist_ids)
             # Genres: all, Artists: all
             else:
                 if Lp().settings.get_value('show-compilations'):
-                    self._albums += Lp().albums.get_compilations()
+                    self._albums += Lp().albums.get_compilation_ids()
                 self._albums += Lp().albums.get_ids()
         # We are in populars view, add popular albums
         elif genre_ids and genre_ids[0] == Type.POPULARS:
@@ -307,17 +308,17 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
             self._albums = Lp().albums.get_cached_randoms()
         # We are in compilation view without genre
         elif genre_ids and genre_ids[0] == Type.COMPILATIONS:
-            self._albums = Lp().albums.get_compilations()
+            self._albums = Lp().albums.get_compilation_ids()
         # Add albums for artists/genres
         else:
             # If we are not in compilation view and show compilation is on,
             # add compilations
             if artist_ids and artist_ids[0] == Type.COMPILATIONS:
-                self._albums += Lp().albums.get_compilations(genre_ids)
+                self._albums += Lp().albums.get_compilation_ids(genre_ids)
             else:
                 if not artist_ids and\
                         Lp().settings.get_value('show-compilations'):
-                    self._albums += Lp().albums.get_compilations(genre_ids)
+                    self._albums += Lp().albums.get_compilation_ids(genre_ids)
                 self._albums += Lp().albums.get_ids(artist_ids, genre_ids)
 
         if Lp().settings.get_value('repeat'):
@@ -520,10 +521,10 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
         mix = Lp().settings.get_value('mix')
         party_mix = Lp().settings.get_value('party-mix')
         self._crossfading = (mix and not party_mix) or\
-                            (mix and party_mix and self._is_party)
+                            (mix and party_mix and self.is_party)
 
 #######################
-# PRIVATE             #
+# PROTECTED           #
 #######################
     def _on_stream_start(self, bus, message):
         """
