@@ -31,24 +31,24 @@ class ShufflePlayer(BasePlayer):
         BasePlayer.__init__(self)
         self.reset_history()
         # Party mode
-        self._is_party = False
-        Lp().settings.connect('changed::shuffle', self._set_shuffle)
+        self.__is_party = False
+        Lp().settings.connect('changed::shuffle', self.___set_shuffle)
 
     def reset_history(self):
         """
             Reset history
         """
         # Tracks already played
-        self._history = []
+        self.__history = []
         # Used by shuffle albums to restore playlist before shuffle
         self._albums_backup = []
         # Albums already played
-        self._already_played_albums = []
+        self.__already_played_albums = []
         # Tracks already played for albums
-        self._already_played_tracks = {}
+        self.__already_played_tracks = {}
         # Reset user playlist
-        self._user_playlist = []
-        self._user_playlist_ids = []
+        self.__user_playlist = []
+        self.__user_playlist_ids = []
 
     def next(self):
         """
@@ -56,11 +56,11 @@ class ShufflePlayer(BasePlayer):
             @return Track
         """
         track_id = None
-        if self._shuffle == Shuffle.TRACKS or self._is_party:
-            if self._history and self._history.has_next():
-                track_id = self._history.get_next().get_value()
+        if self._shuffle == Shuffle.TRACKS or self.__is_party:
+            if self.__history and self.__history.has_next():
+                track_id = self.__history.get_next().get_value()
             elif self._albums:
-                track_id = self._shuffle_next()
+                track_id = self.__shuffle_next()
             else:
                 track_id = self.current_track.id
         return Track(track_id)
@@ -71,9 +71,9 @@ class ShufflePlayer(BasePlayer):
             @return Track
         """
         track_id = None
-        if self._shuffle == Shuffle.TRACKS or self._is_party:
-            if self._history and self._history.has_prev():
-                track_id = self._history.get_prev().get_value()
+        if self._shuffle == Shuffle.TRACKS or self.__is_party:
+            if self.__history and self.__history.has_prev():
+                track_id = self.__history.get_prev().get_value()
             else:
                 track_id = self._current_track.id
         return Track(track_id)
@@ -100,20 +100,20 @@ class ShufflePlayer(BasePlayer):
             Play a new random track if not already playing
             @param party as bool
         """
-        self._is_party = party
+        self.__is_party = party
 
         self.reset_history()
         self._context.genre_ids = {}
 
-        if self.plugins1.rgvolume is not None and\
-           self.plugins2.rgvolume is not None:
+        if self._plugins1.rgvolume is not None and\
+           self._plugins2.rgvolume is not None:
             if party:
                 self._context.next = NextContext.NONE
-                self.plugins1.rgvolume.props.album_mode = 0
-                self.plugins2.rgvolume.props.album_mode = 0
+                self._plugins1.rgvolume.props.album_mode = 0
+                self._plugins2.rgvolume.props.album_mode = 0
             else:
-                self.plugins1.rgvolume.props.album_mode = 1
-                self.plugins2.rgvolume.props.album_mode = 1
+                self._plugins1.rgvolume.props.album_mode = 1
+                self._plugins2.rgvolume.props.album_mode = 1
 
         if party:
             self._external_tracks = []
@@ -136,7 +136,7 @@ class ShufflePlayer(BasePlayer):
             # Start a new song if not playing
             if (self._current_track.id in [None, Type.RADIOS])\
                     and self._albums:
-                track_id = self._get_random()
+                track_id = self.__get_random()
                 self.load(Track(track_id))
             elif not self.is_playing():
                 self.play()
@@ -147,12 +147,13 @@ class ShufflePlayer(BasePlayer):
                                 self._current_track.album.artist_ids, [])
         self.emit('party-changed', party)
 
+    @property
     def is_party(self):
         """
             True if party mode on
             @return bool
         """
-        return self._is_party
+        return self.__is_party
 
     def shuffle_albums(self, shuffle):
         """
@@ -171,26 +172,61 @@ class ShufflePlayer(BasePlayer):
             self._albums = self._albums_backup
             self._albums_backup = []
 
+#######################
+# PROTECTED           #
+#######################
+    def _on_stream_start(self, bus, message):
+        """
+            On stream start add to shuffle history
+        """
+        # Add track to shuffle history if needed
+        if self._shuffle == Shuffle.TRACKS or self.__is_party:
+            if self.__history:
+                next = self.__history.get_next()
+                prev = self.__history.get_prev()
+                # Next track
+                if next is not None and\
+                        self._current_track.id == next.get_value():
+                    next = self.__history.get_next()
+                    next.set_prev(self.__history)
+                    self.__history = next
+                # Previous track
+                elif prev is not None and\
+                        self._current_track.id == prev.get_value():
+                    prev = self.__history.get_prev()
+                    prev.set_next(self.__history)
+                    self.__history = prev
+                # New track
+                elif self.__history.get_value() != self._current_track.id:
+                    new_list = LinkedList(self._current_track.id,
+                                          None,
+                                          self.__history)
+                    self.__history = new_list
+            else:
+                new_list = LinkedList(self._current_track.id)
+                self.__history = new_list
+            self.__add_to_shuffle_history(self._current_track)
+
 #######################
 # PRIVATE             #
 #######################
-    def _set_shuffle(self, settings, value):
+    def ___set_shuffle(self, settings, value):
         """
             Set shuffle mode to gettings value
             @param settings as Gio.Settings, value as str
         """
         self._shuffle = Lp().settings.get_enum('shuffle')
 
-        if self.plugins1.rgvolume is not None and\
-           self.plugins2.rgvolume is not None:
-            if self._shuffle == Shuffle.TRACKS or self._user_playlist:
-                self.plugins1.rgvolume.props.album_mode = 0
-                self.plugins2.rgvolume.props.album_mode = 0
+        if self._plugins1.rgvolume is not None and\
+           self._plugins2.rgvolume is not None:
+            if self._shuffle == Shuffle.TRACKS or self.__user_playlist:
+                self._plugins1.rgvolume.props.album_mode = 0
+                self._plugins2.rgvolume.props.album_mode = 0
             else:
-                self.plugins1.rgvolume.props.album_mode = 1
-                self.plugins2.rgvolume.props.album_mode = 1
+                self._plugins1.rgvolume.props.album_mode = 1
+                self._plugins2.rgvolume.props.album_mode = 1
 
-        if self._user_playlist:
+        if self.__user_playlist:
             self._shuffle_playlist()
         elif self._shuffle == Shuffle.NONE:
             self.shuffle_albums(False)
@@ -199,23 +235,23 @@ class ShufflePlayer(BasePlayer):
         if self._current_track.id is not None:
             self.set_next()
 
-    def _shuffle_next(self):
+    def __shuffle_next(self):
         """
             Next track in shuffle mode
             @return track id as int
         """
         try:
-            track_id = self._get_random()
+            track_id = self.__get_random()
             # Need to clear history
             if track_id is None:
-                self._albums = self._already_played_albums
+                self._albums = self.__already_played_albums
                 self.reset_history()
-                return self._shuffle_next()
+                return self.__shuffle_next()
             return track_id
         except:  # Recursion error
             return None
 
-    def _get_random(self):
+    def __get_random(self):
         """
             Return a random track and make sure it has never been played
         """
@@ -229,58 +265,26 @@ class ShufflePlayer(BasePlayer):
                 genre_ids = []
             tracks = Album(album_id, genre_ids).track_ids
             for track in sorted(tracks, key=lambda *args: random.random()):
-                if album_id not in self._already_played_tracks.keys() or\
-                   track not in self._already_played_tracks[album_id]:
+                if album_id not in self.__already_played_tracks.keys() or\
+                   track not in self.__already_played_tracks[album_id]:
                     return track
             self._finished = NextContext.STOP_ALBUM
             # No new tracks for this album, remove it
             # If albums not in shuffle history, it's not present
             # in db anymore (update since shuffle set)
-            if album_id in self._already_played_tracks.keys():
-                self._already_played_tracks.pop(album_id)
-                self._already_played_albums.append(album_id)
+            if album_id in self.__already_played_tracks.keys():
+                self.__already_played_tracks.pop(album_id)
+                self.__already_played_albums.append(album_id)
             self._albums.remove(album_id)
         self._finished = NextContext.STOP_ALL
         return None
 
-    def _add_to_shuffle_history(self, track):
+    def __add_to_shuffle_history(self, track):
         """
             Add a track to shuffle history
             @param track as Track
         """
-        if track.album_id not in self._already_played_tracks.keys():
-            self._already_played_tracks[track.album_id] = []
-        if track.id not in self._already_played_tracks[track.album_id]:
-            self._already_played_tracks[track.album_id].append(track.id)
-
-    def _on_stream_start(self, bus, message):
-        """
-            On stream start add to shuffle history
-        """
-        # Add track to shuffle history if needed
-        if self._shuffle == Shuffle.TRACKS or self._is_party:
-            if self._history:
-                next = self._history.get_next()
-                prev = self._history.get_prev()
-                # Next track
-                if next is not None and\
-                        self._current_track.id == next.get_value():
-                    next = self._history.get_next()
-                    next.set_prev(self._history)
-                    self._history = next
-                # Previous track
-                elif prev is not None and\
-                        self._current_track.id == prev.get_value():
-                    prev = self._history.get_prev()
-                    prev.set_next(self._history)
-                    self._history = prev
-                # New track
-                elif self._history.get_value() != self._current_track.id:
-                    new_list = LinkedList(self._current_track.id,
-                                          None,
-                                          self._history)
-                    self._history = new_list
-            else:
-                new_list = LinkedList(self._current_track.id)
-                self._history = new_list
-            self._add_to_shuffle_history(self._current_track)
+        if track.album_id not in self.__already_played_tracks.keys():
+            self.__already_played_tracks[track.album_id] = []
+        if track.id not in self.__already_played_tracks[track.album_id]:
+            self.__already_played_tracks[track.album_id].append(track.id)
