@@ -13,7 +13,7 @@
 from gi.repository import Gtk, GLib, Pango
 
 from lollypop.define import Lp
-from lollypop.tagreader import ScannerTagReader
+from lollypop.tagreader import TagReader
 from lollypop.utils import seconds_to_string
 
 
@@ -28,15 +28,15 @@ class ExternalsPopover(Gtk.Popover):
         """
         Gtk.Popover.__init__(self)
         self.set_position(Gtk.PositionType.BOTTOM)
-        self.connect('unmap', self._on_self_unmap)
+        self.connect('unmap', self.__on_self_unmap)
         builder = Gtk.Builder()
         builder.add_from_resource('/org/gnome/Lollypop/ExternalsPopover.ui')
         builder.connect_signals(self)
 
-        self._signal_id = None
-        self._view = builder.get_object('view')
-        self._model = builder.get_object('model')
-        self._tagreader = ScannerTagReader()
+        self.__signal_id = None
+        self.__view = builder.get_object('view')
+        self.__model = builder.get_object('model')
+        self.__tagreader = TagReader()
 
         renderer0 = Gtk.CellRendererPixbuf()
         renderer1 = Gtk.CellRendererText()
@@ -59,10 +59,10 @@ class ExternalsPopover(Gtk.Popover):
         column.add_attribute(renderer3, 'text', 4)
         column.set_expand(True)
         column.set_sizing(Gtk.TreeViewColumnSizing.FIXED)
-        self._view.append_column(column)
-        self.add(self._view)
-        self._signal_id = Lp().player.connect('current-changed',
-                                              self._on_current_changed)
+        self.__view.append_column(column)
+        self.add(self.__view)
+        self.__signal_id = Lp().player.connect('current-changed',
+                                               self.__on_current_changed)
         height = Lp().window.get_size()[1]
         self.set_size_request(400, height*0.7)
 
@@ -70,67 +70,12 @@ class ExternalsPopover(Gtk.Popover):
         """
             Populate popover
         """
-        self._model.clear()
-        self._populate(Lp().player.get_externals())
+        self.__model.clear()
+        self.__populate(Lp().player.get_externals())
 
 #######################
-# PRIVATE             #
+# PROTECTED           #
 #######################
-    def _populate(self, tracks):
-        """
-            Populate popover
-            @param tracks as [Track]
-            @thread safe
-        """
-        for track in tracks:
-            if track.duration == 0.0:
-                try:
-                    infos = self._tagreader.get_infos(track.path)
-                    if infos is not None:
-                        tags = infos.get_tags()
-                        track.duration = infos.get_duration()/1000000000
-                        track.name = self._tagreader.get_title(tags,
-                                                               track.path)
-                        track.artist_names = self._tagreader.get_artists(tags)
-                except Exception as e:
-                    print("ExternalsPopover::_populate(): %s" % e)
-                    track.name = track.uri
-            GLib.idle_add(self._add_track, track)
-
-    def _add_track(self, track):
-        """
-            Add track to model
-            @param track as Track
-            @param filepath as string
-        """
-        if track.uri == Lp().player.current_track.uri:
-            self._model.append((track.uri, 'media-playback-start-symbolic',
-                                track.artist, track.title,
-                                seconds_to_string(track.duration)))
-        else:
-            self._model.append((track.uri, '', track.artist, track.title,
-                                seconds_to_string(track.duration)))
-
-    def _on_self_unmap(self, widget):
-        """
-            Disconnect signals and destroy
-            @param widget as Gtk.Widget
-        """
-        if self._signal_id is not None:
-            Lp().player.disconnect(self._signal_id)
-        GLib.idle_add(self.destroy)
-
-    def _on_current_changed(self, player):
-        """
-            Update play symbol
-            @param player as Player
-        """
-        for item in self._model:
-            if item[0] == player.current_track.uri:
-                item[1] = 'media-playback-start-symbolic'
-            else:
-                item[1] = ''
-
     def _on_row_activated(self, view, path, column):
         """
             Play selected track
@@ -139,7 +84,65 @@ class ExternalsPopover(Gtk.Popover):
             @param column as Gtk.TreeViewColumn
         """
         if path is not None:
-            iterator = self._model.get_iter(path)
+            iterator = self.__model.get_iter(path)
             if iterator is not None:
-                uri = self._model.get_value(iterator, 0)
+                uri = self.__model.get_value(iterator, 0)
                 Lp().player.play_this_external(uri)
+
+#######################
+# PRIVATE             #
+#######################
+    def __populate(self, tracks):
+        """
+            Populate popover
+            @param tracks as [Track]
+            @thread safe
+        """
+        for track in tracks:
+            if track.duration == 0.0:
+                try:
+                    info = self.__tagreader.get_info(track.path)
+                    if info is not None:
+                        tags = info.get_tags()
+                        track.duration = info.get_duration()/1000000000
+                        track.name = self.__tagreader.get_title(tags,
+                                                                track.path)
+                        track.artist_names = self.__tagreader.get_artists(tags)
+                except Exception as e:
+                    print("ExternalsPopover::__populate(): %s" % e)
+                    track.name = track.uri
+            GLib.idle_add(self.__add_track, track)
+
+    def __add_track(self, track):
+        """
+            Add track to model
+            @param track as Track
+            @param filepath as string
+        """
+        if track.uri == Lp().player.current_track.uri:
+            self.__model.append((track.uri, 'media-playback-start-symbolic',
+                                track.artist, track.title,
+                                seconds_to_string(track.duration)))
+        else:
+            self.__model.append((track.uri, '', track.artist, track.title,
+                                seconds_to_string(track.duration)))
+
+    def __on_self_unmap(self, widget):
+        """
+            Disconnect signals and destroy
+            @param widget as Gtk.Widget
+        """
+        if self.__signal_id is not None:
+            Lp().player.disconnect(self.__signal_id)
+        GLib.idle_add(self.destroy)
+
+    def __on_current_changed(self, player):
+        """
+            Update play symbol
+            @param player as Player
+        """
+        for item in self.__model:
+            if item[0] == player.current_track.uri:
+                item[1] = 'media-playback-start-symbolic'
+            else:
+                item[1] = ''
