@@ -56,12 +56,12 @@ class QueueMenu(BaseMenu):
             @param is album as bool
         """
         BaseMenu.__init__(self, object_id, genre_ids, artist_ids, is_album)
-        self._set_queue_actions()
+        self.__set_queue_actions()
 
 #######################
 # PRIVATE             #
 #######################
-    def _set_queue_actions(self):
+    def __set_queue_actions(self):
         """
             Set queue actions
         """
@@ -80,9 +80,9 @@ class QueueMenu(BaseMenu):
                 delete = False
         else:
 
-            tracks = Lp().albums.get_tracks(self._object_id,
-                                            self._genre_ids,
-                                            self._artist_ids)
+            tracks = Lp().albums.get_track_ids(self._object_id,
+                                               self._genre_ids,
+                                               self._artist_ids)
             union = set(queue) & set(tracks)
             if len(union) == len(tracks):
                 append = False
@@ -98,43 +98,44 @@ class QueueMenu(BaseMenu):
         Lp().add_action(del_queue_action)
         if append:
             append_queue_action.connect('activate',
-                                        self._append_to_queue)
+                                        self.__append_to_queue)
             self.append(_("Add to queue"), 'app.append_queue_action')
         if prepend:
             prepend_queue_action.connect('activate',
-                                         self._insert_in_queue)
+                                         self.__insert_in_queue)
             if self._is_album:
                 self.append(_("Next tracks"), 'app.prepend_queue_action')
             else:
                 self.append(_("Next track"), 'app.prepend_queue_action')
         if delete:
             del_queue_action.connect('activate',
-                                     self._del_from_queue)
+                                     self.__del_from_queue)
             self.append(_("Remove from queue"), 'app.del_queue_action')
 
-    def _append_to_queue(self, action, variant):
+    def __append_to_queue(self, action, variant):
         """
             Append track to queue
             @param SimpleAction
             @param GVariant
         """
         if self._is_album:
-            for track_id in Lp().albums.get_tracks(self._object_id,
-                                                   self._genre_ids,
-                                                   self._artist_ids):
+            for track_id in Lp().albums.get_track_ids(self._object_id,
+                                                      self._genre_ids,
+                                                      self._artist_ids):
                 Lp().player.append_to_queue(track_id, False)
         else:
             Lp().player.append_to_queue(self._object_id, False)
         Lp().player.emit('queue-changed')
 
-    def _insert_in_queue(self, action, variant):
+    def __insert_in_queue(self, action, variant):
         """
             Prepend track id to queue
             @param SimpleAction
             @param GVariant
         """
         if self._is_album:
-            for track_id in reversed(Lp().albums.get_tracks(self._object_id,
+            for track_id in reversed(Lp().albums.get_track_ids(
+                                                            self._object_id,
                                                             self._genre_ids,
                                                             self._artist_ids)):
                 Lp().player.insert_in_queue(track_id, 0, False)
@@ -142,16 +143,16 @@ class QueueMenu(BaseMenu):
             Lp().player.insert_in_queue(self._object_id, 0, False)
         Lp().player.emit('queue-changed')
 
-    def _del_from_queue(self, action, variant):
+    def __del_from_queue(self, action, variant):
         """
             Delete track id from queue
             @param SimpleAction
             @param GVariant
         """
         if self._is_album:
-            for track_id in Lp().albums.get_tracks(self._object_id,
-                                                   self._genre_ids,
-                                                   self._artist_ids):
+            for track_id in Lp().albums.get_track_ids(self._object_id,
+                                                      self._genre_ids,
+                                                      self._artist_ids):
                 Lp().player.del_from_queue(track_id, False)
         else:
             Lp().player.del_from_queue(self._object_id, False)
@@ -172,19 +173,19 @@ class PlaylistsMenu(BaseMenu):
             @param is album as bool
         """
         BaseMenu.__init__(self, object_id, genre_ids, artist_ids, is_album)
-        self._set_playlist_actions()
+        self.__set_playlist_actions()
 
 #######################
 # PRIVATE             #
 #######################
-    def _set_playlist_actions(self):
+    def __set_playlist_actions(self):
         """
             Set playlist actions
         """
         playlist_action = Gio.SimpleAction(name="playlist_action")
         Lp().add_action(playlist_action)
         playlist_action.connect('activate',
-                                self._add_to_playlists)
+                                self.__add_to_playlists)
         self.append(_("Add to others"), 'app.playlist_action')
 
         i = 0
@@ -201,19 +202,19 @@ class PlaylistsMenu(BaseMenu):
                                                      self._object_id)
             if exists:
                 action.connect('activate',
-                               self._remove_from_playlist,
+                               self.__remove_from_playlist,
                                playlist[0])
                 self.append(_("Remove from \"%s\"") % playlist[1],
                             "app.playlist%s" % i)
             else:
                 action.connect('activate',
-                               self._add_to_playlist,
+                               self.__add_to_playlist,
                                playlist[0])
                 self.append(_("Add to \"%s\"") % playlist[1],
                             "app.playlist%s" % i)
             i += 1
 
-    def _add_to_playlists(self, action, variant):
+    def __add_to_playlists(self, action, variant):
         """
             Add to playlists
             @param SimpleAction
@@ -224,7 +225,7 @@ class PlaylistsMenu(BaseMenu):
                                           self._artist_ids,
                                           self._is_album)
 
-    def _add_to_playlist(self, action, variant, playlist_id):
+    def __add_to_playlist(self, action, variant, playlist_id):
         """
             Add to playlist
             @param SimpleAction
@@ -234,9 +235,9 @@ class PlaylistsMenu(BaseMenu):
         def add(playlist_id):
             tracks = []
             if self._is_album:
-                track_ids = Lp().albums.get_tracks(self._object_id,
-                                                   self._genre_ids,
-                                                   self._artist_ids)
+                track_ids = Lp().albums.get_track_ids(self._object_id,
+                                                      self._genre_ids,
+                                                      self._artist_ids)
                 for track_id in track_ids:
                     tracks.append(Track(track_id))
             else:
@@ -249,7 +250,7 @@ class PlaylistsMenu(BaseMenu):
         t.daemon = True
         t.start()
 
-    def _remove_from_playlist(self, action, variant, playlist_id):
+    def __remove_from_playlist(self, action, variant, playlist_id):
         """
             Del from playlist
             @param SimpleAction
@@ -261,9 +262,9 @@ class PlaylistsMenu(BaseMenu):
         def remove(playlist_id):
             tracks = []
             if self._is_album:
-                track_ids = Lp().albums.get_tracks(self._object_id,
-                                                   self._genre_ids,
-                                                   self._artist_ids)
+                track_ids = Lp().albums.get_track_ids(self._object_id,
+                                                      self._genre_ids,
+                                                      self._artist_ids)
                 for track_id in track_ids:
                     tracks.append(Track(track_id))
             else:
@@ -276,7 +277,7 @@ class PlaylistsMenu(BaseMenu):
         t.daemon = True
         t.start()
 
-    def _add_to_loved(self, action, variant):
+    def __add_to_loved(self, action, variant):
         """
             Add to loved
             @param SimpleAction
@@ -285,7 +286,7 @@ class PlaylistsMenu(BaseMenu):
         """
         utils.set_loved(self._object_id, True)
 
-    def _del_from_loved(self, action, variant):
+    def __del_from_loved(self, action, variant):
         """
             Remove from loved
             @param SimpleAction
@@ -306,7 +307,7 @@ class PopToolbarMenu(Gio.Menu):
             @param object id as int
         """
         Gio.Menu.__init__(self)
-        if not Lp().player.is_party():
+        if not Lp().player.is_party:
             builder = Gtk.Builder()
             builder.add_from_resource('/org/gnome/Lollypop/PlaybackMenu.ui')
             playback_menu = builder.get_object('playback-menu')
@@ -314,14 +315,14 @@ class PopToolbarMenu(Gio.Menu):
                             'playback',
                             GLib.VariantType.new("s"),
                             GLib.Variant("s", str(Lp().player.context.next)))
-            playback_action.connect('change-state', self._on_change_state)
+            playback_action.connect('change-state', self.__on_change_state)
             Lp().add_action(playback_action)
             self.insert_section(0, _("Playback"),
                                 playback_menu)
         self.insert_section(1, _("Playlists"),
                             PlaylistsMenu(object_id, [], [], False))
 
-    def _on_change_state(self, action, value):
+    def __on_change_state(self, action, value):
         """
             Update playback value
             @param action as Gio.SimpleAction
@@ -335,7 +336,7 @@ class EditMenu(BaseMenu):
     """
         Edition menu for album
     """
-    _TAG_EDITORS = ['exfalso', 'easytag', 'picard', 'puddletag', 'kid3-qt']
+    __TAG_EDITORS = ['exfalso', 'easytag', 'picard', 'puddletag', 'kid3-qt']
 
     def __init__(self, object_id, is_album):
         """
@@ -347,30 +348,30 @@ class EditMenu(BaseMenu):
 
         if is_album:
             favorite = Lp().settings.get_value('tag-editor').get_string()
-            for editor in [favorite] + self._TAG_EDITORS:
+            for editor in [favorite] + self.__TAG_EDITORS:
                 if which(editor) is not None:
-                    self._tag_editor = editor
-                    self._set_edit_actions()
+                    self.__tag_editor = editor
+                    self.__set_edit_actions()
                     break
 
-    def _set_edit_actions(self):
+    def __set_edit_actions(self):
         """
             Set edit actions
         """
         edit_tag_action = Gio.SimpleAction(name="edit_tag_action")
         Lp().add_action(edit_tag_action)
         edit_tag_action.connect('activate',
-                                self._edit_tag)
+                                self.__edit_tag)
         self.append(_("Modify information"), 'app.edit_tag_action')
 
-    def _edit_tag(self, action, variant):
+    def __edit_tag(self, action, variant):
         """
             Run tag editor
             @param SimpleAction
             @param GVariant
         """
         album_path = Lp().albums.get_path(self._object_id)
-        argv = [self._tag_editor, album_path, None]
+        argv = [self.__tag_editor, album_path, None]
         GLib.spawn_async_with_pipes(
                                 None, argv, None,
                                 GLib.SpawnFlags.SEARCH_PATH |
@@ -429,6 +430,12 @@ class TrackMenuPopover(Gtk.Popover):
         Gtk.Popover.__init__(self)
         self.bind_model(menu, None)
 
+        track = Track(object_id)
+        if track.year != track.album.year:
+            track_year = str(track.year)
+        else:
+            track_year = ""
+
         rating = RatingWidget(Track(object_id))
         rating.set_margin_top(5)
         rating.set_margin_bottom(5)
@@ -440,10 +447,24 @@ class TrackMenuPopover(Gtk.Popover):
         loved.set_margin_end(5)
         loved.set_margin_top(5)
         loved.set_margin_bottom(5)
-        loved.set_property('halign', Gtk.Align.END)
+        if track_year == "":
+            loved.set_property('halign', Gtk.Align.END)
+        else:
+            loved.set_property('halign', Gtk.Align.CENTER)
         loved.set_property('hexpand', True)
         loved.show()
 
+        if track_year != "":
+            year = Gtk.Label()
+            year.set_text(track_year)
+            year.set_margin_end(5)
+            year.set_margin_top(5)
+            year.set_margin_bottom(5)
+            year.get_style_context().add_class('dim-label')
+            year.set_property('halign', Gtk.Align.END)
+            year.set_property('hexpand', True)
+            year.show()
+
         # Hack to add two widgets in popover
         # Use a Gtk.PopoverMenu later (GTK>3.16 available on Debian stable)
         grid = Gtk.Grid()
@@ -463,6 +484,8 @@ class TrackMenuPopover(Gtk.Popover):
         hgrid = Gtk.Grid()
         hgrid.add(rating)
         hgrid.add(loved)
+        if track_year != "":
+            hgrid.add(year)
         hgrid.show()
         grid.add(hgrid)
         self.add(stack)
