@@ -28,17 +28,17 @@ class View(Gtk.Grid):
         self.connect('destroy', self._on_destroy)
         self.set_property('orientation', Gtk.Orientation.VERTICAL)
         self.set_border_width(0)
-        self._current_signal = Lp().player.connect('current-changed',
-                                                   self._on_current_changed)
-        self._cover_signal = Lp().art.connect('album-artwork-changed',
-                                              self._on_cover_changed)
+        self.__current_signal = Lp().player.connect('current-changed',
+                                                    self._on_current_changed)
+        self.__cover_signal = Lp().art.connect('album-artwork-changed',
+                                               self.__on_cover_changed)
 
         # Stop populate thread
         self._stop = False
-        self._new_ids = []
+        self.__new_ids = []
 
         self._scrolled = Gtk.ScrolledWindow()
-        self._scrolled.connect('leave-notify-event', self._on_leave_notify)
+        self._scrolled.connect('leave-notify-event', self.__on_leave_notify)
         self._scrolled.show()
         self._viewport = Gtk.Viewport()
         self._scrolled.add(self._viewport)
@@ -56,7 +56,7 @@ class View(Gtk.Grid):
         """
             Update children
         """
-        GLib.idle_add(self._update_widgets, self._get_children())
+        GLib.idle_add(self.__update_widgets, self._get_children())
 
     def disable_overlays(self):
         """
@@ -68,7 +68,7 @@ class View(Gtk.Grid):
         pass
 
 #######################
-# PRIVATE             #
+# PROTECTED           #
 #######################
     def _disable_overlays(self, widgets):
         """
@@ -80,7 +80,35 @@ class View(Gtk.Grid):
             widget.show_overlay(False)
             GLib.idle_add(self._disable_overlays, widgets)
 
-    def _update_widgets(self, widgets):
+    def _get_children(self):
+        """
+            Return view children
+        """
+        return []
+
+    def _on_current_changed(self, player):
+        """
+            Current song changed
+            @param player as Player
+        """
+        GLib.idle_add(self.__update_widgets, self._get_children())
+
+    def _on_destroy(self, widget):
+        """
+            Remove signals on unamp
+            @param widget as Gtk.Widget
+        """
+        if self.__current_signal:
+            Lp().player.disconnect(self.__current_signal)
+            self.__current_signal = None
+        if self.__cover_signal:
+            Lp().art.disconnect(self.__cover_signal)
+            self.__cover_signal = None
+
+#######################
+# PRIVATE             #
+#######################
+    def __update_widgets(self, widgets):
         """
             Update all widgets
             @param widgets as AlbumWidget
@@ -89,15 +117,9 @@ class View(Gtk.Grid):
             widget = widgets.pop(0)
             widget.update_state()
             widget.update_playing_indicator()
-            GLib.idle_add(self._update_widgets, widgets)
+            GLib.idle_add(self.__update_widgets, widgets)
 
-    def _get_children(self):
-        """
-            Return view children
-        """
-        return []
-
-    def _on_leave_notify(self, widget, event):
+    def __on_leave_notify(self, widget, event):
         """
             Update overlays as internal widget may not have received the signal
             @param widget as Gtk.Widget
@@ -110,19 +132,7 @@ class View(Gtk.Grid):
            event.y >= allocation.height:
             self.disable_overlays()
 
-    def _on_destroy(self, widget):
-        """
-            Remove signals on unamp
-            @param widget as Gtk.Widget
-        """
-        if self._current_signal:
-            Lp().player.disconnect(self._current_signal)
-            self._current_signal = None
-        if self._cover_signal:
-            Lp().art.disconnect(self._cover_signal)
-            self._cover_signal = None
-
-    def _on_cover_changed(self, art, album_id):
+    def __on_cover_changed(self, art, album_id):
         """
             Update album cover in view
             @param art as Art
@@ -132,13 +142,6 @@ class View(Gtk.Grid):
             if album_id == widget.get_id():
                 widget.update_cover()
 
-    def _on_current_changed(self, player):
-        """
-            Current song changed
-            @param player as Player
-        """
-        GLib.idle_add(self._update_widgets, self._get_children())
-
 
 class LazyLoadingView(View):
     """
@@ -152,7 +155,7 @@ class LazyLoadingView(View):
         View.__init__(self)
         self._lazy_queue = []  # Widgets not initialized
         self._scroll_value = 0
-        self._prev_scroll_value = 0
+        self.__prev_scroll_value = 0
         self._scrolled.get_vadjustment().connect('value-changed',
                                                  self._on_value_changed)
 
@@ -171,12 +174,29 @@ class LazyLoadingView(View):
             @param widgets as [AlbumSimpleWidgets]
             @param scroll_value as float
         """
-        GLib.idle_add(self._lazy_loading, widgets, scroll_value)
+        GLib.idle_add(self.__lazy_loading, widgets, scroll_value)
+
+#######################
+# PROTECTED           #
+#######################
+    def _on_value_changed(self, adj):
+        """
+            Update scroll value and check for lazy queue
+            @param adj as Gtk.Adjustment
+        """
+        if not self._lazy_queue:
+            return False
+        scroll_value = adj.get_value()
+        diff = self.__prev_scroll_value - scroll_value
+        if diff > ArtSize.BIG or diff < -ArtSize.BIG:
+            self.__prev_scroll_value = scroll_value
+            GLib.idle_add(self.__lazy_or_not,
+                          scroll_value)
 
 #######################
 # PRIVATE             #
 #######################
-    def _lazy_loading(self, widgets=[], scroll_value=0):
+    def __lazy_loading(self, widgets=[], scroll_value=0):
         """
             Load the view in a lazy way:
                 - widgets first
@@ -199,7 +219,7 @@ class LazyLoadingView(View):
             else:
                 GLib.idle_add(self.lazy_loading, widgets, scroll_value)
 
-    def _is_visible(self, widget):
+    def __is_visible(self, widget):
         """
             Is widget visible in scrolled
             @param widget as Gtk.Widget
@@ -213,7 +233,7 @@ class LazyLoadingView(View):
         except:
             return True
 
-    def _lazy_or_not(self, scroll_value):
+    def __lazy_or_not(self, scroll_value):
         """
             Add visible widgets to lazy queue
             @param scroll value as float
@@ -221,20 +241,6 @@ class LazyLoadingView(View):
         self._scroll_value = scroll_value
         widgets = []
         for child in self._lazy_queue:
-            if self._is_visible(child):
+            if self.__is_visible(child):
                 widgets.append(child)
         GLib.idle_add(self.lazy_loading, widgets, self._scroll_value)
-
-    def _on_value_changed(self, adj):
-        """
-            Update scroll value and check for lazy queue
-            @param adj as Gtk.Adjustment
-        """
-        if not self._lazy_queue:
-            return False
-        scroll_value = adj.get_value()
-        diff = self._prev_scroll_value - scroll_value
-        if diff > ArtSize.BIG or diff < -ArtSize.BIG:
-            self._prev_scroll_value = scroll_value
-            GLib.idle_add(self._lazy_or_not,
-                          scroll_value)
