@@ -31,19 +31,19 @@ class AlbumsView(LazyLoadingView):
             @param artist ids as [int]
         """
         LazyLoadingView.__init__(self)
-        self._signal = None
-        self._context_album_id = None
-        self._genre_ids = genre_ids
-        self._artist_ids = artist_ids
-        self._press_rect = None
+        self.__signal = None
+        self.__context_album_id = None
+        self.__genre_ids = genre_ids
+        self.__artist_ids = artist_ids
+        self.__press_rect = None
 
-        self._albumbox = Gtk.FlowBox()
-        self._albumbox.set_selection_mode(Gtk.SelectionMode.NONE)
-        self._albumbox.connect('child-activated', self._on_album_activated)
-        self._albumbox.connect('button-press-event', self._on_button_press)
-        self._albumbox.set_homogeneous(True)
-        self._albumbox.set_max_children_per_line(1000)
-        self._albumbox.show()
+        self.__albumbox = Gtk.FlowBox()
+        self.__albumbox.set_selection_mode(Gtk.SelectionMode.NONE)
+        self.__albumbox.connect('child-activated', self.__on_album_activated)
+        self.__albumbox.connect('button-press-event', self.__on_button_press)
+        self.__albumbox.set_homogeneous(True)
+        self.__albumbox.set_max_children_per_line(1000)
+        self.__albumbox.show()
 
         self._viewport.set_property('valign', Gtk.Align.START)
         self._viewport.set_property('margin', 5)
@@ -55,7 +55,7 @@ class AlbumsView(LazyLoadingView):
             Populate albums
             @param is compilation as bool
         """
-        GLib.idle_add(self._add_albums, albums)
+        GLib.idle_add(self.__add_albums, albums)
 
     def stop(self):
         """
@@ -66,7 +66,7 @@ class AlbumsView(LazyLoadingView):
             child.stop()
 
 #######################
-# PRIVATE             #
+# PROTECTED           #
 #######################
     def _disable_overlays(self, widgets):
         """
@@ -81,11 +81,14 @@ class AlbumsView(LazyLoadingView):
             @return [AlbumWidget]
         """
         children = []
-        for child in self._albumbox.get_children():
+        for child in self.__albumbox.get_children():
             children.append(child)
         return children
 
-    def _add_albums(self, albums):
+#######################
+# PRIVATE             #
+#######################
+    def __add_albums(self, albums):
         """
             Add albums to the view
             Start lazy loading
@@ -96,18 +99,18 @@ class AlbumsView(LazyLoadingView):
             return
         if albums:
             widget = AlbumSimpleWidget(albums.pop(0),
-                                       self._genre_ids,
-                                       self._artist_ids)
-            self._albumbox.insert(widget, -1)
+                                       self.__genre_ids,
+                                       self.__artist_ids)
+            self.__albumbox.insert(widget, -1)
             widget.show()
             self._lazy_queue.append(widget)
-            GLib.idle_add(self._add_albums, albums)
+            GLib.idle_add(self.__add_albums, albums)
         else:
             GLib.idle_add(self.lazy_loading)
             if self._viewport.get_child() is None:
-                self._viewport.add(self._albumbox)
+                self._viewport.add(self.__albumbox)
 
-    def _on_album_activated(self, flowbox, album_widget):
+    def __on_album_activated(self, flowbox, album_widget):
         """
             Show Context view for activated album
             @param flowbox as Gtk.Flowbox
@@ -120,14 +123,14 @@ class AlbumsView(LazyLoadingView):
         # FIXME: Report a bug and check always true
         (x, y) = album_widget.translate_coordinates(self._scrolled, 0, 0)
         if y < 0:
-            y = album_widget.translate_coordinates(self._albumbox, 0, 0)[1]
+            y = album_widget.translate_coordinates(self.__albumbox, 0, 0)[1]
             self._scrolled.get_allocation().height + y
             self._scrolled.get_vadjustment().set_value(y)
-        if self._press_rect is not None:
+        if self.__press_rect is not None:
             pop_menu = AlbumMenu(Album(album_widget.get_id()))
             popover = Gtk.Popover.new_from_model(cover, pop_menu)
             popover.set_position(Gtk.PositionType.BOTTOM)
-            popover.set_pointing_to(self._press_rect)
+            popover.set_pointing_to(self.__press_rect)
         else:
             allocation = self.get_allocation()
             (x, top_height) = album_widget.translate_coordinates(self, 0, 0)
@@ -139,8 +142,8 @@ class AlbumsView(LazyLoadingView):
             else:
                 height = top_height
             popover = AlbumPopover(album_widget.get_id(),
-                                   self._genre_ids,
-                                   self._artist_ids,
+                                   self.__genre_ids,
+                                   self.__artist_ids,
                                    allocation.width,
                                    height,
                                    False)
@@ -148,11 +151,11 @@ class AlbumsView(LazyLoadingView):
             popover.set_position(Gtk.PositionType.BOTTOM)
         album_widget.show_overlay(False)
         album_widget.lock_overlay(True)
-        popover.connect('closed', self._on_popover_closed, album_widget)
+        popover.connect('closed', self.__on_popover_closed, album_widget)
         popover.show()
         cover.set_opacity(0.9)
 
-    def _on_popover_closed(self, popover, album_widget):
+    def __on_popover_closed(self, popover, album_widget):
         """
             @param popover as Gtk.Popover
             @param album_widget as AlbumWidget
@@ -160,17 +163,17 @@ class AlbumsView(LazyLoadingView):
         album_widget.lock_overlay(False)
         album_widget.get_cover().set_opacity(1)
 
-    def _on_button_press(self, flowbox, event):
+    def __on_button_press(self, flowbox, event):
         """
             Store pressed button
             @param flowbox as Gtk.Flowbox
             @param event as Gdk.EventButton
         """
         if event.button == 1:
-            self._press_rect = None
+            self.__press_rect = None
         else:
-            self._press_rect = Gdk.Rectangle()
-            self._press_rect.x = event.x
-            self._press_rect.y = event.y
-            self._press_rect.width = self._press_rect.height = 1
+            self.__press_rect = Gdk.Rectangle()
+            self.__press_rect.x = event.x
+            self.__press_rect.y = event.y
+            self.__press_rect.width = self.__press_rect.height = 1
             event.button = 1
