@@ -33,12 +33,12 @@ class PlaylistsView(View):
             @param editable as bool
         """
         View.__init__(self)
-        self._tracks = []
-        self._playlist_ids = playlist_ids
-        self._signal_id1 = Lp().playlists.connect('playlist-add',
-                                                  self._on_playlist_add)
-        self._signal_id2 = Lp().playlists.connect('playlist-del',
-                                                  self._on_playlist_del)
+        self.__tracks = []
+        self.__playlist_ids = playlist_ids
+        self.__signal_id1 = Lp().playlists.connect('playlist-add',
+                                                   self.__on_playlist_add)
+        self.__signal_id2 = Lp().playlists.connect('playlist-del',
+                                                   self.__on_playlist_del)
 
         builder = Gtk.Builder()
         builder.add_from_resource('/org/gnome/Lollypop/PlaylistView.ui')
@@ -47,18 +47,18 @@ class PlaylistsView(View):
         builder.get_object('title').set_label(
                              ", ".join(Lp().playlists.get_names(playlist_ids)))
 
-        self._edit_button = builder.get_object('edit-button')
-        self._jump_button = builder.get_object('jump-button')
+        self.__edit_button = builder.get_object('edit-button')
+        self.__jump_button = builder.get_object('jump-button')
 
         if len(playlist_ids) > 1 or (
            playlist_ids[0] < 0 and playlist_ids[0] != Type.LOVED) or\
                 not editable:
-            self._edit_button.hide()
+            self.__edit_button.hide()
 
-        self._playlists_widget = PlaylistsWidget(playlist_ids)
-        self._playlists_widget.show()
+        self.__playlists_widget = PlaylistsWidget(playlist_ids)
+        self.__playlists_widget.show()
         self.add(builder.get_object('widget'))
-        self._viewport.add(self._playlists_widget)
+        self._viewport.add(self.__playlists_widget)
         self._scrolled.set_property('expand', True)
         self.add(self._scrolled)
 
@@ -93,68 +93,34 @@ class PlaylistsView(View):
             if count >= half:
                 break
             mid_tracks += 1
-        self._tracks = tracks
-        self._update_jump_button()
-        self._playlists_widget.populate_list_left(tracks[:mid_tracks],
-                                                  1)
-        self._playlists_widget.populate_list_right(tracks[mid_tracks:],
-                                                   mid_tracks + 1)
+        self.__tracks = tracks
+        self.__update_jump_button()
+        self.__playlists_widget.populate_list_left(tracks[:mid_tracks],
+                                                   1)
+        self.__playlists_widget.populate_list_right(tracks[mid_tracks:],
+                                                    mid_tracks + 1)
 
     def get_ids(self):
         """
             Return playlist ids
             @return id as [int]
         """
-        return self._playlist_ids
+        return self.__playlist_ids
 
     def stop(self):
         """
             Stop populating
         """
-        self._playlists_widget.stop()
+        self.__playlists_widget.stop()
 
 #######################
-# PRIVATE             #
+# PROTECTED           #
 #######################
     def _get_children(self):
         """
             Return view children
         """
-        return [self._playlists_widget]
-
-    def _update_jump_button(self):
-        """
-            Update jump button status
-        """
-        if Lp().player.current_track.id in self._tracks:
-            self._jump_button.set_sensitive(True)
-            artists = ", ".join(Lp().player.current_track.artists)
-            self._jump_button.set_tooltip_markup(
-             "<b>%s</b>\n%s" % (escape(artists),
-                                escape(Lp().player.current_track.name)))
-        else:
-            self._jump_button.set_sensitive(False)
-            self._jump_button.set_tooltip_text('')
-
-    def _on_playlist_add(self, manager, playlist_id, track_id):
-        """
-            Update tracks widgets
-            @param manager as PlaylistsManager
-            @param playlist id as int
-            @param track id as int
-        """
-        if playlist_id in self._playlist_ids:
-            self._playlists_widget.append(track_id)
-
-    def _on_playlist_del(self, manager, playlist_id, track_id):
-        """
-            Update tracks widgets
-            @param manager as PlaylistsManager
-            @param playlist id as int
-            @param track id as int
-        """
-        if playlist_id in self._playlist_ids:
-            self._playlists_widget.remove(track_id)
+        return [self.__playlists_widget]
 
     def _on_destroy(self, widget):
         """
@@ -162,19 +128,19 @@ class PlaylistsView(View):
             @param widget as Gtk.Widget
         """
         View._on_destroy(self, widget)
-        if self._signal_id1:
-            Lp().playlists.disconnect(self._signal_id1)
-            self._signal_id1 = None
-        if self._signal_id2:
-            Lp().playlists.disconnect(self._signal_id2)
-            self._signal_id2 = None
+        if self.__signal_id1:
+            Lp().playlists.disconnect(self.__signal_id1)
+            self.__signal_id1 = None
+        if self.__signal_id2:
+            Lp().playlists.disconnect(self.__signal_id2)
+            self.__signal_id2 = None
 
     def _on_jump_button_clicked(self, button):
         """
             Scroll to current track
             @param button as Gtk.Button
         """
-        y = self._playlists_widget.get_current_ordinate()
+        y = self.__playlists_widget.get_current_ordinate()
         if y is not None:
             self._scrolled.get_vadjustment().set_value(y)
 
@@ -183,7 +149,7 @@ class PlaylistsView(View):
             Edit playlist
             @param button as Gtk.Button
         """
-        Lp().window.show_playlist_editor(self._playlist_ids[0])
+        Lp().window.show_playlist_editor(self.__playlist_ids[0])
 
     def _on_current_changed(self, player):
         """
@@ -191,7 +157,44 @@ class PlaylistsView(View):
             @param player as Player
         """
         View._on_current_changed(self, player)
-        self._update_jump_button()
+        self.__update_jump_button()
+
+#######################
+# PRIVATE             #
+#######################
+    def __update_jump_button(self):
+        """
+            Update jump button status
+        """
+        if Lp().player.current_track.id in self.__tracks:
+            self.__jump_button.set_sensitive(True)
+            artists = ", ".join(Lp().player.current_track.artists)
+            self.__jump_button.set_tooltip_markup(
+             "<b>%s</b>\n%s" % (escape(artists),
+                                escape(Lp().player.current_track.name)))
+        else:
+            self.__jump_button.set_sensitive(False)
+            self.__jump_button.set_tooltip_text('')
+
+    def __on_playlist_add(self, manager, playlist_id, track_id):
+        """
+            Update tracks widgets
+            @param manager as PlaylistsManager
+            @param playlist id as int
+            @param track id as int
+        """
+        if playlist_id in self.__playlist_ids:
+            self.__playlists_widget.append(track_id)
+
+    def __on_playlist_del(self, manager, playlist_id, track_id):
+        """
+            Update tracks widgets
+            @param manager as PlaylistsManager
+            @param playlist id as int
+            @param track id as int
+        """
+        if playlist_id in self.__playlist_ids:
+            self.__playlists_widget.remove(track_id)
 
 
 class PlaylistsManageView(View):
@@ -215,12 +218,12 @@ class PlaylistsManageView(View):
         if object_id != Type.NONE:
             builder.get_object('back_btn').show()
         builder.connect_signals(self)
-        self._manage_widget = PlaylistsManagerWidget(object_id,
-                                                     genre_ids,
-                                                     artist_ids,
-                                                     is_album)
-        self._manage_widget.show()
-        self._viewport.add(self._manage_widget)
+        self.__manage_widget = PlaylistsManagerWidget(object_id,
+                                                      genre_ids,
+                                                      artist_ids,
+                                                      is_album)
+        self.__manage_widget.show()
+        self._viewport.add(self.__manage_widget)
         self.add(builder.get_object('widget'))
         self.add(self._scrolled)
 
@@ -228,17 +231,17 @@ class PlaylistsManageView(View):
         """
             Populate the view
         """
-        self._manage_widget.populate()
+        self.__manage_widget.populate()
 
 #######################
-# PRIVATE             #
+# PROTECTED           #
 #######################
     def _on_new_clicked(self, widget):
         """
             Add new playlist
             @param widget as Gtk.Button
         """
-        self._manage_widget.add_new_playlist()
+        self.__manage_widget.add_new_playlist()
 
     def _on_back_btn_clicked(self, button):
         """
@@ -268,19 +271,19 @@ class PlaylistEditView(View):
         builder.connect_signals(self)
         grid = builder.get_object('widget')
         self.add(grid)
-        self._edit_widget = PlaylistEditWidget(playlist_id)
-        self._edit_widget.show()
-        self._viewport.add(self._edit_widget)
+        self.__edit_widget = PlaylistEditWidget(playlist_id)
+        self.__edit_widget.show()
+        self._viewport.add(self.__edit_widget)
         self.add(self._scrolled)
 
     def populate(self):
         """
             Populate view
         """
-        self._edit_widget.populate()
+        self.__edit_widget.populate()
 
 #######################
-# PRIVATE             #
+# PROTECTED           #
 #######################
     def _on_back_btn_clicked(self, button):
         """
